@@ -24,7 +24,8 @@ class MarkdownRenderer:
 
     # CUSTOMIZATION
     from ._customization import set_font_sizes, set_font, reload_fonts, set_line_gaps, set_color_hline, \
-        set_color_code_background, set_color_font, set_color_quote, set_color_background, set_scroll_step
+        set_color_code_background, set_color_font, set_color_quote, set_color_background, set_scroll_step, \
+        render_background
 
     def __init__(self):
         self.x: int = None
@@ -79,7 +80,7 @@ class MarkdownRenderer:
 
         self.html = ""
         self.blocks = []
-        self.render_background = True
+        self.background_rendering = True
 
     def set_markdown(self, mdfile_path):
         # load md file and parse to HTML
@@ -152,7 +153,7 @@ class MarkdownRenderer:
         :return:
         """
         # Background
-        if self.render_background:
+        if self.background_rendering:
             # with reversed margins
             pygame.draw.rect(self.screen, self.color_area_background,
                              (self.x - self.margin, self.y - self.margin, self.w + (2 * self.margin),
